==> org.opennms.features.telemetry.protocols.netflow.parser-24.0.0-20181220.200826-21-sources.jar: org/opennms/netmgt/telemetry/protocols/netflow/parser/session/Session.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.protocols.netflow.parser.session;

import java.util.Collection;
import java.util.List;
import java.util.Optional;

import org.opennms.netmgt.telemetry.protocols.netflow.parser.ie.Value;

public interface Session {

    interface Resolver {
        Optional<Template> lookupTemplate(final int templateId);
        List<Value<?>> lookupOptions(final List<Value<?>> values);
    }

    void addTemplate(final long observationDomainId, final Template template);

    void removeTemplate(final long observationDomainId, final int templateId);

    void removeAllTemplate(final long observationDomainId, final Template.Type type);

    void addOptions(final long observationDomainId,
                    final int templateId,
                    final Collection<Value<?>> scopes,
                    final List<Value<?>> values);

    Resolver getResolver(final long observationDomainId);

}

==> org.opennms.features.telemetry.protocols.netflow.parser-25.0.0-20190321.021951-17-sources.jar: org/opennms/netmgt/telemetry/protocols/netflow/parser/session/Session.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.protocols.netflow.parser.session;

import java.util.Collection;
import java.util.List;
import java.util.Optional;

import org.opennms.netmgt.telemetry.protocols.netflow.parser.MissingTemplateException;
import org.opennms.netmgt.telemetry.protocols.netflow.parser.ie.Value;

public interface Session {

    interface Resolver {
        Template lookupTemplate(final int templateId) throws MissingTemplateException;
        List<Value<?>> lookupOptions(final List<Value<?>> values);
    }

    void addTemplate(final long observationDomainId, final Template template);

    void removeTemplate(final long observationDomainId, final int templateId);

    void removeAllTemplate(final long observationDomainId, final Template.Type type);

    void addOptions(final long observationDomainId,
                    final int templateId,
                    final Collection<Value<?>> scopes,
                    final List<Value<?>> values);

    Resolver getResolver(final long observationDomainId);

}
